# coding: utf-8
from enum import Enum, unique


@unique
class RecurringIndicator(Enum):
    
    REGULAR_TRANSACTION = "REGULAR_TRANSACTION"
    INITIAL_RECURRING_TRANSACTION = "INITIAL_RECURRING_TRANSACTION"
    MERCHANT_INITIATED_RECURRING_TRANSACTION = "MERCHANT_INITIATED_RECURRING_TRANSACTION"
    CUSTOMER_INITIATED_RECURRING_TRANSACTION = "CUSTOMER_INITIATED_RECURRING_TRANSACTION"

